Estimators
==========

This section provides detailed documentation for each tail index estimator in the tailestim package.

.. toctree::
   :maxdepth: 2
   
   hill
   kernel
   moments
   pickands
   smooth_hill